<?php
/**
 * Add metabox to posts
 *
 * @package Magazinex
 */

// Only needed for the admin side
if ( ! is_admin() ) {
	return;
}

/**
 * Helper function stars up meta class
 */
function magazinex_page_meta_init() {
	new MAGAZINEX_Page_Meta_Settings();
}

/**
 * Calls the class on the post edit screen.
 */
add_action( 'load-post.php', 'magazinex_page_meta_init' );
add_action( 'load-post-new.php', 'magazinex_page_meta_init' );

/** 
 * The Class.
 */
class MAGAZINEX_Page_Meta_Settings {

	/**
	 * Hook into the appropriate actions when the class is constructed.
	 */
	public function __construct() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );
		add_action( 'save_post', array( $this, 'save' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_css' ) );
	}

	/**
	 * Adds the meta box container.
	 */
	public function add_meta_box( $post_type ) {
		if ( 'page' == $post_type ) {
			add_meta_box(
				'magazinex_page_settings_metabox',
				esc_html__( 'Sidebar Layout', 'magazinex-lite' ),
				array( $this, 'render_meta_box_content' ),
				'page',
				'side',
				'core'
			);
		}
	}

	/**
	 * Render Meta Box content.
	 *
	 * @param WP_Post $post The post object.
	 */
	public function render_meta_box_content( $post ) {
	
		// Add an nonce field so we can check for it later.
		wp_nonce_field( 'magazinex_meta_action', 'magazinex_meta_action_nonce' );

			// Use get_post_meta to retrieve an existing value from the database.
			$value = esc_attr( get_post_meta( $post->ID, 'magazinex_post_layout', true ) );

			// Layout options
			$post_layouts = array(
				''               	=> esc_html__( 'Default', 'magazinex-lite' ),
				'right-sidebar'  	=> esc_html__( 'Right Sidebar', 'magazinex-lite' ),
				'left-sidebar'   	=> esc_html__( 'Left Sidebar', 'magazinex-lite' ),
			);

			// Display the form, using the current value.
			echo '<label class="screen-reader-text" for="parent_id">' . esc_html__( 'Sidebar Layout', 'magazinex-lite' ) . '</label>';
				echo '<select type="text" id="magazinex_post_layout" name="magazinex_post_layout">';
					foreach( $post_layouts as $key => $val ) {
						echo '<option value="'. esc_attr( $key ) .'" '. selected( $value, $key ) .'>'. esc_attr( $val ) .'</option>';
					}
				echo '</select>';

	}

	/**
	 * Save the meta when the post is saved.
	 *
	 * @param int $post_id The ID of the post being saved.
	 */
	public function save( $post_id ) {
	
		/*
		 * We need to verify this came from the our screen and with proper authorization,
		 * because save_post can be triggered at other times.
		 */

		// Check if our nonce is set.
		if ( ! isset( $_POST['magazinex_meta_action_nonce'] ) ) {
			return $post_id;
		}

		$nonce = $_POST['magazinex_meta_action_nonce'];

		// Verify that the nonce is valid.
		if ( ! wp_verify_nonce( $nonce, 'magazinex_meta_action' ) ) {
			return $post_id;
		}

		// If this is an autosave, our form has not been submitted,
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		// Check the user's permissions.
		if ( 'page' == $_POST['post_type'] ) {

			if ( ! current_user_can( 'edit_page', $post_id ) ) {
				return $post_id;
			}
	
		} else {

			if ( ! current_user_can( 'edit_post', $post_id ) ) {
				return $post_id;
			}

		}

		/* OK, its safe for us to save the data now. */

			// Save Post Layout
			$val = isset( $_POST['magazinex_post_layout'] ) ? sanitize_text_field( $_POST['magazinex_post_layout'] ) : '';
			update_post_meta( $post_id, 'magazinex_post_layout', $val );

	}

	/**
	 * Adds metabox CSS
	 */
	public function load_css( $hook ) {
		if ( $hook == 'post.php' || $hook == 'post-new.php' ) {
			wp_enqueue_style( 'magazinex-metaboxes', get_template_directory_uri() .'/css/metaboxes.css' );
		}
	}

}